# Licensed under the MIT License
# https://github.com/craigahobbs/template-specialize/blob/main/LICENSE

"""
template-specialize top-level script environment
"""

from .main import main


if __name__ == '__main__': # pragma: no cover
    main()
